@@ -13,9 +13,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * @author  Gary Cramblitt <garycramblitt@comcast.net> (original author)
  *
@@ -299,10 +298,6 @@ static void *_ibmtts_play(void *);
 static void *_ibmtts_stop_or_pause(void *);
 
 /* Module configuration options. */
-/* TODO: Remove these if we decide they aren't needed. */
-MOD_OPTION_1_INT(IbmttsMaxChunkLength);
-MOD_OPTION_1_STR(IbmttsDelimiters);
-
 MOD_OPTION_1_INT(IbmttsUseSSML);
 MOD_OPTION_1_STR(IbmttsPunctuationList);
 MOD_OPTION_1_INT(IbmttsUseAbbreviation);
@@ -402,10 +397,6 @@ int module_load(void)
 
 	REGISTER_DEBUG();
 
-	/* TODO: Remove these if we decide they aren't needed. */
-	MOD_OPTION_1_INT_REG(IbmttsMaxChunkLength, 3000);
-	MOD_OPTION_1_STR_REG(IbmttsDelimiters, "");
-
 	MOD_OPTION_1_INT_REG(IbmttsUseSSML, 1);
 	MOD_OPTION_1_INT_REG(IbmttsUseAbbreviation, 1);
 	MOD_OPTION_1_STR_REG(IbmttsPunctuationList, "()?");
@@ -511,10 +502,6 @@ int module_init(char **status_info)
 	   playback threads. */
 	pthread_mutex_init(&playback_queue_mutex, NULL);
 
-	/*
-	   DBG("Ibmtts: IbmttsMaxChunkLength = %d", IbmttsMaxChunkLength);
-	   DBG("Ibmtts: IbmttsDelimiters = %s", IbmttsDelimiters);
-	 */
 	DBG("Ibmtts: ImbttsAudioChunkSize = %d", IbmttsAudioChunkSize);
 
 	ibmtts_message = g_malloc(sizeof(char *));
@@ -587,8 +574,8 @@ int module_speak(gchar * data, size_t bytes, SPDMessageType msgtype)
 		return IBMTTS_FALSE;
 	}
 
-	DBG("Ibmtts: Type: %d, bytes: %d, requested data: |%s|\n", msgtype,
-	    bytes, data);
+	DBG("Ibmtts: Type: %d, bytes: %lu, requested data: |%s|\n", msgtype,
+	    (unsigned long)bytes, data);
 
 	g_free(*ibmtts_message);
 	*ibmtts_message = NULL;
@@ -1390,7 +1377,6 @@ static enum ECICallbackReturn eciCallback(ECIHand hEngine,
 					  enum ECIMessage msg,
 					  long lparam, void *data)
 {
-	int ret;
 	/* This callback is running in the same thread as called eciSynchronize(),
 	   i.e., the _ibmtts_synth() thread. */
 
@@ -1402,7 +1388,7 @@ static enum ECICallbackReturn eciCallback(ECIHand hEngine,
 	case eciWaveformBuffer:
 		DBG("Ibmtts: %ld audio samples returned from IBM TTS.", lparam);
 		/* Add audio to output queue. */
-		ret = ibmtts_add_audio_to_playback_queue(audio_chunk, lparam);
+		ibmtts_add_audio_to_playback_queue(audio_chunk, lparam);
 		/* Wake up the audio playback thread, if not already awake. */
 		if (!is_thread_busy(&ibmtts_play_suspended_mutex))
 			sem_post(&ibmtts_play_semaphore);
@@ -1414,7 +1400,7 @@ static enum ECICallbackReturn eciCallback(ECIHand hEngine,
 			ibmtts_add_flag_to_playback_queue(IBMTTS_QET_END);
 		} else {
 			/* Add index mark to output queue. */
-			ret = ibmtts_add_mark_to_playback_queue(lparam);
+			ibmtts_add_mark_to_playback_queue(lparam);
 		}
 		/* Wake up the audio playback thread, if not already awake. */
 		if (!is_thread_busy(&ibmtts_play_suspended_mutex))
@@ -1745,7 +1731,7 @@ void alloc_voice_list()
 	if (!ibmtts_voice_list)
 		return;
 
-	DBG("Ibmtts: nLanguages=%d/%d", nLanguages, MAX_NB_OF_LANGUAGES);
+	DBG("Ibmtts: nLanguages=%d/%lu", nLanguages, (unsigned long)MAX_NB_OF_LANGUAGES);
 	for (i = 0; i < nLanguages; i++) {
 		/* look for the language name */
 		int j;
