@@ -14,9 +14,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this package; see the file COPYING.  If not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * $Id: module_utils_addvoice.c,v 1.5 2007-07-29 23:43:33 hanke Exp $
  */
@@ -35,6 +33,11 @@
 
 GHashTable *module_voice_table = NULL;
 
+static int nbvoices=0;
+static int nbpaths=0;
+static SPDVoice *generic_voices;
+static SPDVoice **generic_voices_list;
+static char **dependency_paths;
 typedef struct {
 	char *male1;
 	char *male2;
@@ -46,8 +49,18 @@ typedef struct {
 	char *child_female;
 } SPDVoiceDef;
 
+DOTCONF_CB(VoiceFileDependency_cb)
+{
+	dependency_paths = (char **)g_realloc(dependency_paths, (nbpaths + 1) * sizeof *dependency_paths);
+	dependency_paths[nbpaths] = g_strdup(cmd->data.str);
+	++nbpaths;
+	return NULL;
+}
+
 DOTCONF_CB(AddVoice_cb)
 {
+	int i=0;
+	GRegex *regex;
 	SPDVoiceDef *voices;
 	char *language = cmd->data.list[0];
 	char *symbolic;
@@ -115,10 +128,38 @@ DOTCONF_CB(AddVoice_cb)
 		DBG("Unrecognized voice name in configuration\n");
 		return NULL;
 	}
-
+	regex = g_regex_new("[$]VOICE", 0, 0, NULL);
+	for (i = 0; i < nbpaths; i++)
+	{
+		char *new_dependency_path = g_regex_replace_literal(regex, dependency_paths[i], -1, 0, cmd->data.list[2], 0, NULL);
+		if (! g_file_test(new_dependency_path, G_FILE_TEST_EXISTS)) {
+			g_free(new_dependency_path);
+			g_regex_unref(regex);
+			return NULL;
+		}
+		g_free(new_dependency_path);
+	}
+	g_regex_unref(regex);
+	generic_voices = (SPDVoice *)g_realloc(generic_voices, (nbvoices+1) * sizeof(SPDVoice));
+	generic_voices_list = (SPDVoice **)g_realloc(generic_voices_list, (nbvoices+2) * sizeof(SPDVoice *));
+	generic_voices[nbvoices].name = g_strdup(cmd->data.list[2]);
+	generic_voices[nbvoices].language = g_strdup(cmd->data.list[0]);
+	generic_voices[nbvoices].variant = g_strdup(cmd->data.list[1]);;
+	for (i = 0; i < nbvoices+1; i++)
+		generic_voices_list[i] = &generic_voices[i];
+	generic_voices_list[nbvoices+1] = NULL;
+	++nbvoices;
 	return NULL;
 }
 
+void module_register_available_voices(void)
+{
+	module_dc_options = module_add_config_option(module_dc_options,
+						     &module_num_dc_options,
+						     "VoiceFileDependency", ARG_STR,
+						     VoiceFileDependency_cb, NULL, 0);
+}
+
 void module_register_settings_voices(void)
 {
 	module_voice_table = g_hash_table_new(g_str_hash, g_str_equal);
@@ -128,6 +169,20 @@ void module_register_settings_voices(void)
 						     AddVoice_cb, NULL, 0);
 }
 
+gboolean module_existsvoice(char *voicename)
+{
+	int i;
+	for (i = 0; generic_voices_list[i] != NULL; i++) {
+	if (strcasecmp(generic_voices[i].name, voicename) == 0)
+		return TRUE;
+	}
+	return FALSE;
+}
+
+SPDVoice **module_list_registered_voices(void) {
+	return (SPDVoice **)generic_voices_list;
+}
+
 char *module_getvoice(char *language, SPDVoiceType voice)
 {
 	SPDVoiceDef *voices;
